# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .node_input_compiled_array_value import NodeInputCompiledArrayValue
from .node_input_compiled_chat_history_value import NodeInputCompiledChatHistoryValue
from .node_input_compiled_error_value import NodeInputCompiledErrorValue
from .node_input_compiled_function_call import NodeInputCompiledFunctionCall
from .node_input_compiled_json_value import NodeInputCompiledJsonValue
from .node_input_compiled_number_value import NodeInputCompiledNumberValue
from .node_input_compiled_search_results_value import NodeInputCompiledSearchResultsValue
from .node_input_compiled_string_value import NodeInputCompiledStringValue


class NodeInputVariableCompiledValue_String(NodeInputCompiledStringValue):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NodeInputVariableCompiledValue_Number(NodeInputCompiledNumberValue):
    type: typing.Literal["NUMBER"] = "NUMBER"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NodeInputVariableCompiledValue_Json(NodeInputCompiledJsonValue):
    type: typing.Literal["JSON"] = "JSON"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NodeInputVariableCompiledValue_ChatHistory(NodeInputCompiledChatHistoryValue):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NodeInputVariableCompiledValue_SearchResults(NodeInputCompiledSearchResultsValue):
    type: typing.Literal["SEARCH_RESULTS"] = "SEARCH_RESULTS"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NodeInputVariableCompiledValue_Error(NodeInputCompiledErrorValue):
    type: typing.Literal["ERROR"] = "ERROR"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NodeInputVariableCompiledValue_Array(NodeInputCompiledArrayValue):
    type: typing.Literal["ARRAY"] = "ARRAY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NodeInputVariableCompiledValue_FunctionCall(NodeInputCompiledFunctionCall):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


NodeInputVariableCompiledValue = typing.Union[
    NodeInputVariableCompiledValue_String,
    NodeInputVariableCompiledValue_Number,
    NodeInputVariableCompiledValue_Json,
    NodeInputVariableCompiledValue_ChatHistory,
    NodeInputVariableCompiledValue_SearchResults,
    NodeInputVariableCompiledValue_Error,
    NodeInputVariableCompiledValue_Array,
    NodeInputVariableCompiledValue_FunctionCall,
]
