# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .error_vellum_value import ErrorVellumValue
from .function_call_vellum_value import FunctionCallVellumValue
from .json_vellum_value import JsonVellumValue
from .string_vellum_value import StringVellumValue


class PromptOutput_String(StringVellumValue):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class PromptOutput_Json(JsonVellumValue):
    type: typing.Literal["JSON"] = "JSON"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class PromptOutput_Error(ErrorVellumValue):
    type: typing.Literal["ERROR"] = "ERROR"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class PromptOutput_FunctionCall(FunctionCallVellumValue):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


PromptOutput = typing.Union[PromptOutput_String, PromptOutput_Json, PromptOutput_Error, PromptOutput_FunctionCall]
