# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .deployment_release_tag_deployment_history_item import DeploymentReleaseTagDeploymentHistoryItem
from .release_tag_source import ReleaseTagSource


class DeploymentReleaseTagRead(pydantic_v1.BaseModel):
    name: str = pydantic_v1.Field()
    """
    The name of the Release Tag
    """

    source: ReleaseTagSource = pydantic_v1.Field()
    """
    The source of how the Release Tag was originally created
    
    - `SYSTEM` - System
    - `USER` - User
    """

    history_item: DeploymentReleaseTagDeploymentHistoryItem = pydantic_v1.Field()
    """
    The Deployment History Item that this Release Tag is associated with
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
